@@ -13,7 +13,7 @@ from resource_man.importlib_interface import \
 from resource_man.interface import \
     ResourceNotAvailable, Resource, ResourceManagerInterface, ResourceManager, \
     get_global_manager, set_global_manager, temp_manager, add_manager, remove_manager, clear, \
-    register, register_data, register_directory, unregister, has_resource, \
+    register_resource, register, register_data, register_directory, unregister, has_resource, \
     get_resources, get_resource, get_binary, get_text, registered_datas, \
     MISSING
 
@@ -25,7 +25,7 @@ __all__ = [
 
     'ResourceNotAvailable', 'Resource', 'ResourceManagerInterface', 'ResourceManager',
     'get_global_manager', 'set_global_manager', 'temp_manager', 'add_manager', 'remove_manager',
-    'clear', 'register', 'register_data', 'register_directory', 'unregister',
+    'clear', 'register_resource', 'register', 'register_data', 'register_directory', 'unregister',
     'has_resource', 'get_resources', 'get_resource', 'get_binary', 'get_text', 'registered_datas',
     'MISSING',
     '__version__'
@@ -35,12 +35,13 @@ __all__ = [
 EXCLUDE_EXT = SOURCE_SUFFIXES + ['.pyc', '.pyd']
 
 
-def find_datas(package, exclude_ext=None, **kwargs):
+def find_datas(package, exclude_ext=None, use_dest_dirs=True, **kwargs):
     """Collect data files for pyinstaller.
 
     Args:
         package (types.ModuleType/str/Traversable): Top level package module or module name.
         exclude_ext (list)[None]: List of extensions to not include in the pyinstaller data.
+        use_dest_dirs (bool)[True]: If True the destination will be a directory. If False the dest will be the filename.
 
     Returns:
         datas (list): List of (abs file path, rel install path). This will also include subdirectories.
@@ -78,8 +79,12 @@ def find_datas(package, exclude_ext=None, **kwargs):
                             filename = str(filename.resolve())
                         except (AttributeError, Exception):
                             pass
+
                         relpath = os.path.join(pkg_name, os.path.relpath(filename, toplvl_filename))
-                        data = (filename, os.path.dirname(relpath))
+                        if use_dest_dirs:
+                            relpath = os.path.dirname(relpath)
+
+                        data = (filename, relpath)
                         if data not in datas:
                             datas.append(data)
 
